# encoding: utf-8
"""
@project: djangoModel->standing_book_apis
@author: 孙楷炎
@Email: sky4834@163.com
@synopsis:
@created_time: 2023/3/24 9:47
"""
import time

from rest_framework.views import APIView

from ..services.homepage_statistics_services import HomepageStatisticsServices
from ..services.standing_book_services import StandingBookServices
from ..utils.custom_response import util_response
from ..utils.custom_tool import request_params_wrapper


class HomepageStatisticsApis(APIView):
    @request_params_wrapper
    def statistics(self, *args, request_params, **kwargs):
        data, err = HomepageStatisticsServices.statistics()
        if err:
            return util_response(err=1000, msg=err)
        return util_response(data=data)




import sys

from orator import DatabaseManager
from decimal import Decimal
from config.config import JConfig
from xj_behavior.utils.utility_method import get_chinese_initials
from xj_finance.utils.utility_method import generate_code

config = JConfig()
db_config = {
    config.get('main', 'driver', "mysql"): {
        'driver': config.get('main', 'driver', "mysql"),
        'host': config.get('main', 'mysql_host', "127.0.0.1"),
        'database': config.get('main', 'mysql_database', ""),
        'user': config.get('main', 'mysql_user', "root"),
        'password': config.get('main', 'mysql_password', "123456"),
        "port": config.getint('main', 'mysql_port', "3306")
    }
}
db = DatabaseManager(db_config)


class ContractIntegrationServices():

    # 合同添加
    @staticmethod
    def contract_add(contract):

        contract_data = {}

        if not sys.modules.get("xj_thread.services.thread_category_service.ThreadCategoryService"):
            from xj_thread.services.thread_category_service import ThreadCategoryService
            category, category_err = ThreadCategoryService.list(params={"value": "LABOR_CONTRACT"})
            if not category['list'] and category_err:
                return None, category_err
            category_id = category['list'][0]['id']
        # ——————————————————————————————检查企业用户start———————————————————————————————————————————— #
        if not sys.modules.get("xj_user.services.user_detail_info_service.DetailInfoService"):
            from xj_user.services.user_detail_info_service import DetailInfoService
            corporate_account, err = DetailInfoService.get_detail(
                user_id=contract.get("corporate_account_id", ""))
            if err:
                return None, err
            # ——————————————————————————————检查企业用户end———————————————————————————————————————————— #

            # ——————————————————————————————检查客户start———————————————————————————————————————————— #
            user_name, err = DetailInfoService.get_detail(
                search_params={"nickname": contract.get("nickname", "")})
            if user_name:
                user_id = user_name['user_id']
            else:
                # 3、如果不存在该客户创建（不用登录的客户,不会隶属于组织结构，会绑定到企业账号旗下）
                if not sys.modules.get("xj_user.services.user_service.UserService"):
                    from xj_user.services.user_service import UserService
                    user, user_err = UserService.user_add({
                        'nickname': contract.get("nickname", ""),
                        'full_name': contract.get("nickname", ""),
                        'user_type': "UNKNOWN"
                    })
                    if user_err:
                        return None, user_err
                    user_id = user['user_id']
                # 4、第一次录入 自动绑定客户账户和企业账户隶属关系
                if not sys.modules.get("xj_user.services.user_service.UserService"):
                    from xj_user.services.user_relate_service import UserRelateToUserService
                    user_enterprise, user_enterprise_err = UserRelateToUserService.laowu_bind_bxtx_relate(
                        {"user_id_list": user_id, "with_user_id": contract.get("corporate_account_id", ""),
                         "relate_key": "belong"})
                    if user_enterprise_err:
                        return None, user_enterprise_err
            # ——————————————————————————————检查客户end———————————————————————————————————————————— #

        # ——————————————————————————————根据企业用户生成合同start———————————————————————————————————————————— #
        # 如何合同编码不存在 则为生成编码
        if not contract.get("transact_no", ""):
            initials = get_chinese_initials(corporate_account.get("nickname", ""))
            transact_no = generate_code("HL_" + str(initials))
            contract_data['transact_no'] = transact_no
        # ——————————————————————————————根据企业用户生成合同end———————————————————————————————————————————— #

        # ——————————————————————————————合同数据录入start———————————————————————————————————————————— #
        contract_data['user_id'] = user_id  # 客户id
        contract_data['with_user_id'] = contract.get("salesman_id", "")  # 业务员id
        contract_data['group_id'] = contract.get("group_id", "")  # 业务员所属大区
        contract_data['category_id'] = category_id
        # 9、查询合同是否存在 如果已经存在导入的合同隶属主合同 后续统计合同金额累加
        if not sys.modules.get("xj_thread.services.thread_item_service.ThreadItemService"):
            from xj_thread.services.thread_item_service import ThreadItemService
            thread_detail, thread_err_detail = ThreadItemService.detail(
                search_params={"transact_no": contract_data.get("transact_no", ""), "category_id": category_id},
                sort="id")
            if thread_detail:
                contract_data['main_thread_id'] = thread_detail['id']
                contract_data['is_subitem_thread'] = 1
            # 10、合同数据录入
            thread, thread_err = ThreadItemService.add(contract_data)
            if thread_err:
                return None, thread_err
            # ——————————————————————————————合同数据录入end———————————————————————————————————————————— #

        contract_id = thread.get("id")

        if contract_data.get("main_thread_id", ""):
            contract_id = contract_data.get("main_thread_id", "")

        contract_detail, contract_err = ThreadItemService.detail(contract_id)
        if contract_err:
            return None, contract_err

        return {"contract_id": contract_detail['id'], "transact_no": contract_detail['transact_no']}, None

    # 合同整合添加
    @staticmethod
    def writing(request_params):
        corporate_account_id = request_params.get("corporate_account_id", "")
        if not corporate_account_id:
            return None, "隶属企业不能为空"
        contract = request_params.get("contract", "")
        invoice = request_params.get("invoice", "")
        finance = request_params.get("finance", "")
        if contract:
            contract['corporate_account_id'] = corporate_account_id
            contract_service, contract_err = ContractIntegrationServices.contract_add(contract)
            if contract_err:
                return None, contract_err
            print("合同")

        if invoice:
            if not sys.modules.get("xj_invoice.services.invoice_service.InvoiceService"):
                from xj_invoice.services.invoice_service import InvoiceService
                for item in invoice:
                    item['thread_id'] = contract_service.get("contract_id", "")
                invoice_service, invoice_err = InvoiceService.batch_add({"invoice_list": invoice})
                if invoice_err:
                    return None, invoice_err
            print("发票")
        if finance:
            if not sys.modules.get("xj_finance.services.finance_labor_service.FinanceLaborService"):
                from xj_finance.services.finance_labor_service import FinanceLaborService
                finance['order_no'] = contract_service.get("transact_no", "")
                finance_service, finance_err = FinanceLaborService.larbor_add(finance)
                if finance_err:
                    return None, finance_err
            print("财务")

        return None, None

    # 合同加载查询
    @staticmethod
    def contract_load(request_params):
        results = db.table('thread as t') \
            .select(
            't.*',
            'u.nickname',
            'g.group_name'
        ) \
            .left_join('user_base_info as u', 't.user_id', '=', 'u.id') \
            .left_join('role_user_group as g', 't.group_id', '=', 'g.id') \
            .where_raw('t.category_id=160') \
            .group_by('transact_no')

        results_list = results.items

        return results_list, None



# encoding: utf-8
'''
@project: djangoModel->StandingBookServices
@author: 孙楷炎
@Email: sky4834@163.com
@synopsis: 台账服务
@created_time: 2023/3/24 10:07
'''
from orator import DatabaseManager

from config.config import JConfig
from xj_enroll.api.enroll_apis import EnrollAPI
from xj_enroll.service.enroll_record_serivce import EnrollRecordServices
from xj_finance.services.finance_transacts_service import FinanceTransactsService
from xj_role.services.user_group_service import UserGroupService
from xj_user.services.user_relate_service import UserRelateToUserService
from ..utils.custom_tool import force_transform_type
from ..utils.join_list import JoinList

config = JConfig()
db_config = {
    config.get('main', 'driver', "mysql"): {
        'driver': config.get('main', 'driver', "mysql"),
        'host': config.get('main', 'mysql_host', "127.0.0.1"),
        'database': config.get('main', 'mysql_database', ""),
        'user': config.get('main', 'mysql_user', "root"),
        'password': config.get('main', 'mysql_password', "123456"),
        "port": config.getint('main', 'mysql_port', "3306")
    }
}
db = DatabaseManager(db_config)


class StandingBookServices():
    @staticmethod
    def standing_book(params: dict = None):
        """
        请求参数：params
        :param params: 筛选参数
        :return: list,err
        """
        page = int(params.get("page", 1))
        size = int(params.get("size", 10))

        enroll_result, err = EnrollAPI.list_handle(request_params=params)
        enroll_list = enroll_result['list']
        # print(enroll_list)
        user_id_list = list(set([i['user_id'] for i in enroll_list]))
        enroll_id_list = list(set([i['id'] for i in enroll_list]))
        # 权限模块获取部门
        group_names, err = UserGroupService.get_user_group_info(user_id_list=user_id_list,
                                                                field_list=['group_name', 'user_id'])
        # 获取业务人员
        beneficiary_users, err = UserRelateToUserService.list(
            params={'relate_key': 'beneficiary', "user_id_list": user_id_list, 'need_pagination': 0})
        beneficiary_user_map = {i["user_id"]: i["with_user_name"] for i in beneficiary_users or []}
        # 获取接单人员
        enroll_record_list, err = EnrollRecordServices.record_list(
            params={"enroll_id_list": enroll_id_list},
            need_pagination=False
        )
        enroll_record_map = {}
        for i in enroll_record_list:
            if enroll_record_map.get(i["enroll"]):
                enroll_record_map[i["enroll"]].append(i.get("full_name", "该用户不存在"))
            else:
                enroll_record_map[i["enroll"]] = [i.get("full_name", "该用户不存在")]

        current_index = (page - 1) * size
        # 获取发票相关的信息
        for item in enroll_list:
            # 添加
            group_names_str = ""
            for i in group_names.get(item.get("user_id", ""), []):
                group_names_str = group_names_str + ("," if len(group_names_str) > 0 else "") + i["group_name"]
            item["group_name"] = "游客" if not group_names_str else group_names_str  # 分组字符串

            current_index += 1
            item["index"] = current_index  # 序号
            item["beneficiary"] = beneficiary_user_map.get(item.get("user_id"), "非业务人员邀请用户")  # 邀请用户
            item["total"] = item.get("count", 0) * item.get("price", 0)  # 小计
            item["beneficiary_amount"] = float(item.get("amount", 0)) * 0.6  # 业务员提成
            item["urge_free"] = 50 if isinstance(item.get("is_urgent", None), str) and int(
                item["is_urgent"]) else 0  # 加急费用
            item["other_money"] = '-'  # 其他款项

            enroll_user_name_str = ""
            for i in enroll_record_map.get(item["id"], []):
                enroll_user_name_str = enroll_user_name_str + ("," if len(enroll_user_name_str) > 0 else "") + (i or "")
            item["enroll_user_names"] = enroll_user_name_str  # 报名名称

        enroll_result['list'] = enroll_list
        # 资金相关的数据
        finance_list, err = FinanceTransactsService.finance_standing_book(params={"enroll_id_list": enroll_id_list})
        JoinList.left_join(l_list=enroll_result['list'], r_list=finance_list, l_key="id", r_key="enroll_id")

        return enroll_result, None

    @staticmethod
    def __get_beneficiary_level(user_id, invite_relate_type_id):
        invite_user_map = {}
        first_invite_user = db.table("user_relate_to_user"). \
            where("user_relate_to_user.user_id", '=', user_id). \
            where("user_relate_type_id", invite_relate_type_id). \
            pluck('with_user_id')
        if first_invite_user:
            invite_user_map[first_invite_user] = 1

        second_invite_user = None
        if first_invite_user:
            second_invite_user = db.table("user_relate_to_user"). \
                where("user_relate_to_user.user_id", first_invite_user). \
                where("user_relate_type_id", invite_relate_type_id). \
                pluck('with_user_id')
            if second_invite_user:
                invite_user_map[second_invite_user] = 2

        if second_invite_user:
            third_invite_user = db.table("user_relate_to_user"). \
                where("user_relate_to_user.user_id", second_invite_user). \
                where("user_relate_type_id", invite_relate_type_id). \
                pluck('with_user_id')
            if third_invite_user:
                invite_user_map[third_invite_user] = 3

        return invite_user_map

    @staticmethod
    def standing_book_v2(params: dict):
        params, err = force_transform_type(variable=params, var_type="dict", default={})
        # 获取项目信息
        enroll_result, err = EnrollAPI.list_handle(request_params=params)
        enroll_list = enroll_result['list']

        # 获取业务员相关信息
        enroll_to_user_map = {i["id"]: i["user_id"] for i in enroll_list}
        invite_relate_type_id = db.table("user_relate_type").where("relate_key", "invite").pluck('id')
        beneficiary_relate_type_id = db.table("user_relate_type").where("relate_key", "beneficiary").pluck('id')
        # ------------------------------- section 找到这一批人的业务人员的相关信息 start -------------------------------------------
        # 第一步、获取客户绑定的业务人员列表，找到了业务人员
        beneficiary_user_set = db.table("user_relate_to_user").select(
            'user_relate_to_user.user_id',
            'user_relate_to_user.with_user_id',
            "user_base_info.user_name",
            "user_base_info.full_name",
            "user_detail_info.real_name"
        ). \
            left_join("user_base_info", 'user_relate_to_user.with_user_id', '=', 'user_base_info.id'). \
            left_join("user_detail_info", 'user_relate_to_user.with_user_id', '=', 'user_detail_info.user_id'). \
            where_in("user_relate_to_user.user_id", list(set(enroll_to_user_map.values()))). \
            where("user_relate_type_id", beneficiary_relate_type_id). \
            get()
        beneficiary_id_map = {i["user_id"]: i["with_user_id"] for i in beneficiary_user_set}
        beneficiary_real_name_map = {i["user_id"]: i["real_name"] for i in beneficiary_user_set}

        # 第二步、获取业务的所属部门，找到了业务人员的所属部门
        group_user_set = db.table("role_user_to_group").select(
            'role_user_to_group.user_id',
            'role_user_to_group.user_group_id',
            "role_user_group.group_name",
            "role_user_group.group"
        ). \
            left_join("role_user_group", 'role_user_group.id', '=', 'role_user_to_group.user_group_id'). \
            where_in("role_user_to_group.user_id", list(set([i["with_user_id"] for i in beneficiary_user_set]))). \
            get()
        group_user_map = {}
        for i in group_user_set:
            if group_user_map.get(i["user_id"]):
                group_user_map[i["user_id"]].append(i)
            else:
                group_user_map[i["user_id"]] = [i]

        # 第四步、获取资金相关的信息
        bid_user_pay_map = db.table("finance_transact"). \
            where("income", '>', 0). \
            where_in("enroll_id", list(enroll_to_user_map.keys())).lists('bookkeeping_type', 'enroll_id')

        # 第五步、拼接业务信息
        for i in enroll_result['list']:
            i["beneficiary"] = beneficiary_real_name_map.get(i['user_id'], "--")  # 业务员
            beneficiary_id = beneficiary_id_map.get(i['user_id'], 0)  # 业务员的用户ID
            i["beneficiary_group_name"] = group_user_map.get(beneficiary_id, [])  # 业务人员所属部门
            i["beneficiary_percentage"] = 0  # 业务员提成默认值
            # 获取该用户前三及的邀请人，判断他的业务员是第几级
            invite_relate_level_map = StandingBookServices.__get_beneficiary_level(
                user_id=i["user_id"],
                invite_relate_type_id=invite_relate_type_id
            )
            if beneficiary_id and invite_relate_level_map.get(beneficiary_id) == 1:
                i["beneficiary_percentage"] = float(i["amount"] or 0) * 0.06
            elif beneficiary_id and invite_relate_level_map.get(beneficiary_id) == 2:
                i["beneficiary_percentage"] = float(i["amount"] or 0) * 0.04
            elif beneficiary_id and invite_relate_level_map.get(beneficiary_id) == 3:
                i["beneficiary_percentage"] = float(i["amount"] or 0) * 0.02
            i["beneficiary_percentage"] = round(i["beneficiary_percentage"], 2)

            i["bookkeeping_type"] = bid_user_pay_map.get(i['id'], "-")
        # ------------------------------- section 找到这一批人的业务人员的相关信息 end   -------------------------------------------

        # ------------------------------- section 获取开票信息 start -------------------------------------------
        # 第一步、查询
        # DATE_FORMAT(invoice_time, "%%Y-%%m-%%d %%H:%%i:%%s") as invoice_time,
        invoice_set_list = db.table("invoice_to_enroll"). \
            left_join('invoice_invoice', 'invoice_invoice.id', '=', 'invoice_to_enroll.invoice_id'). \
            left_join('thread', 'thread.id', '=', 'invoice_invoice.thread_id'). \
            select(
            db.raw("""
                enroll_id, 
                thread_id, 
                title,
                DATE_FORMAT(invoice_time, "%%Y-%%m-%%d %%H:%%i:%%s") as invoice_time,
                invoice_type_id, 
                invoice_number, 
                invoice_price, 
                tax_rate, 
                invoice_tax, 
                invoice_status
            """)). \
            where_in('enroll_id', list(set(enroll_to_user_map.keys()))). \
            get()

        # 第二步、拼接数据
        invoice_set_map = {i["enroll_id"]: i for i in invoice_set_list}
        for i in enroll_result['list']:
            i["invoice_title"] = invoice_set_map.get(i["id"], {}).get("title")
            i["invoice_time"] = invoice_set_map.get(i["id"], {}).get("invoice_time")
            i["invoice_type_id"] = invoice_set_map.get(i["id"], {}).get("invoice_type_id")
            i["invoice_number"] = invoice_set_map.get(i["id"], {}).get("invoice_number")
            i["invoice_price"] = invoice_set_map.get(i["id"], {}).get("invoice_price")
            i["tax_rate"] = invoice_set_map.get(i["id"], {}).get("tax_rate")
            i["invoice_tax"] = invoice_set_map.get(i["id"], {}).get("invoice_tax")
            i["invoice_status"] = invoice_set_map.get(i["id"], {}).get("invoice_status")
        # ------------------------------- section 获取开票信息 end   -------------------------------------------

        # ------------------------------- section 获取镖师信息 start -------------------------------------------
        # 获取报名记录相关的信息
        enroll_record_user = db.table("enroll_record"). \
            left_join("user_base_info", "user_base_info.id", '=', 'enroll_record.user_id'). \
            left_join("user_detail_info", "user_detail_info.user_id", '=', 'enroll_record.user_id'). \
            select_raw("""
                enroll_record.enroll_id,
                enroll_record.user_id,
                enroll_record.again_price,
                user_base_info.nickname as record_nickname,
                user_base_info.full_name as record_full_name,
                user_detail_info.real_name as record_real_name
            """). \
            where_in("enroll_record.enroll_id", list(enroll_to_user_map.keys())). \
            where_not_in("enroll_record.enroll_status_code", [124, 234]). \
            get()
        enroll_record_user_map = {i["enroll_id"]: i for i in enroll_record_user}

        # 获取资金相关的信息,286 为平台用户
        bid_worker_pay_record = db.table("finance_transact"). \
            select('transact_time', 'enroll_id', 'account_id', 'income', 'outgo', 'pay_mode_id', 'bookkeeping_type'). \
            where("account_id", '=', 286). \
            where("income", '=', 0). \
            where_in("enroll_id", list(enroll_record_user_map.keys())).get()
        bid_worker_pay_record_map = {i["enroll_id"]: i for i in bid_worker_pay_record}
        # 拼接数据
        for i in enroll_result['list']:
            i["again_price"] = enroll_record_user_map.get(i["id"], {}).get("again_price")
            i["record_nickname"] = enroll_record_user_map.get(i["id"], {}).get("record_nickname")
            i["record_full_name"] = enroll_record_user_map.get(i["id"], {}).get("record_full_name")
            i["record_real_name"] = enroll_record_user_map.get(i["id"], {}).get("record_real_name")
            # 资金余额相关的逻辑
            i["pay_mode_id"] = bid_worker_pay_record_map.get(i["id"], {}).get("pay_mode_id")
            i["record_transact_time"] = bid_worker_pay_record_map.get(i["id"], {}).get("transact_time")
            i["record_outgo"] = bid_worker_pay_record_map.get(i["id"], {}).get("outgo")
            i["record_bookkeeping_type"] = bid_worker_pay_record_map.get(i["id"], {}).get("bookkeeping_type",
                                                                                          '-')  # 镖师佣金的线上和线下支付
        # ------------------------------- section 获取镖师信息 end   -------------------------------------------

        return enroll_result, None



# _*_coding:utf-8_*_
from django.urls import re_path

from .apis.contract_integration_apis import ContractIntegrationApis
from .apis.customer_statistics_apis import CustomerStatisticsApis
from .apis.homepage_statistics_apis import HomepageStatisticsApis
from .apis.standing_book_apis import StandingBookApis

app_name = 'xj_behavior'

# 应用路由
urlpatterns = [
    re_path(r'data?$', StandingBookApis.as_view(), ),
    re_path(r'standing_book_v2?$', StandingBookApis.standing_book_v2, ),
    re_path(r'statistics?$', HomepageStatisticsApis.statistics, ),  # 首页统计（镖镖行）
    re_path(r'customer?$', CustomerStatisticsApis.statistics, ),  # 客户列表（中迈劳务专用）
    re_path(r'contract_add?$', ContractIntegrationApis.contract_add, ),  # 合同添加（中迈劳务专用 需处理逻辑）
    re_path(r'contract_integration_entry?$', ContractIntegrationApis.writing, ),  # 合同、发票、财务整合写入（中迈劳务专用）
]



from setuptools import setup, find_packages

with open('README.md', 'r', encoding='utf8') as fp:
    log_desc = fp.read()

setup(
    name='xj_behavior',  # 模块名称
    version='1.0.11',  # 模块版本
    description='行为模块',  # 项目 摘要描述
    long_description=log_desc,  # 项目描述
    long_description_content_type="text/markdown",  # md文件，markdown格式
    packages=find_packages(),  # 系统自动从当前目录开始找包
    license="apache 3.0",
    install_requires=[]
)



import sys

from orator import DatabaseManager
from decimal import Decimal
from config.config import JConfig
from xj_behavior.utils.utility_method import parse_integers

config = JConfig()
db_config = {
    config.get('main', 'driver', "mysql"): {
        'driver': config.get('main', 'driver', "mysql"),
        'host': config.get('main', 'mysql_host', "127.0.0.1"),
        'database': config.get('main', 'mysql_database', ""),
        'user': config.get('main', 'mysql_user', "root"),
        'password': config.get('main', 'mysql_password', "123456"),
        "port": config.getint('main', 'mysql_port', "3306")
    }
}
db = DatabaseManager(db_config)


class CustomerStatisticsServices():
    @staticmethod
    def statistics(request_params):
        page = int(request_params.get('page', 1))
        size = int(request_params.get('size', 10))
        nickname = request_params.get('nickname', "")
        belong_id_list = request_params.get("belong_id_list", "")
        # 第一部分的子查询
        subquery_t1 = db.table('user_base_info as u') \
            .select(
            'u.id',
            'u.nickname',
            db.raw('count(t.id) as engineering_quantity'),
            db.raw('sum(t.field_1) as total_contract_amount')
        ) \
            .left_join('thread as t', 't.user_id', '=', 'u.id') \
            .where_raw('t.category_id=160') \
            .where_raw('user_type ="UNKNOWN" ') \
            .group_by('u.id')

        # 第二部分的子查询
        subquery_t2 = db.table('user_base_info as u') \
            .select(
            'u.id',
            'u.nickname',
            db.raw('sum(t.field_1) as year_total_contract_amount')
        ) \
            .left_join('thread as t', 't.user_id', '=', 'u.id') \
            .where_raw('t.category_id=160') \
            .where_raw('user_type ="UNKNOWN" ') \
            .where_raw('YEAR(t.create_time) = YEAR(CURDATE())') \
            .group_by('u.id')

        query = db.table(db.raw(f"({subquery_t1.to_sql()}) as t1")) \
            .select(
            't1.id',
            't1.nickname',
            db.raw('engineering_quantity'),
            db.raw('total_contract_amount'),
            db.raw('year_total_contract_amount')
        ) \
            .left_join(db.raw(f"({subquery_t2.to_sql()}) as t2"), 't1.id', '=', 't2.id')

        if belong_id_list:
            belong_list = parse_integers(belong_id_list)
            group_query = db.table('user_relate_to_user').select('user_id').where_in('with_user_id', belong_list).where(
                'user_relate_type_id', 5).get()
            user_ids = [item['user_id'] for item in group_query.items]

        if user_ids:
            query.where_in('user_id', user_ids)
        else:
            query.where_null('user_id')

        if nickname:
            query.where('t1.nickname', 'like', f'%{nickname}%')

        total = query.get().count()

        results = query.paginate(size, page)
        results_list = results.items

        return {'size': size, 'page': page, 'total': total, 'list': results_list}, None



from orator import DatabaseManager
from decimal import Decimal
from config.config import JConfig

config = JConfig()
db_config = {
    config.get('main', 'driver', "mysql"): {
        'driver': config.get('main', 'driver', "mysql"),
        'host': config.get('main', 'mysql_host', "127.0.0.1"),
        'database': config.get('main', 'mysql_database', ""),
        'user': config.get('main', 'mysql_user', "root"),
        'password': config.get('main', 'mysql_password', "123456"),
        "port": config.getint('main', 'mysql_port', "3306")
    }
}
db = DatabaseManager(db_config)


class HomepageStatisticsServices():
    @staticmethod
    def statistics(params: dict = None):
        deal_orders = db.table('enroll_enroll').where_in('enroll_status_code', [80, 668]).count()
        number_escorters = db.table(db.raw(f"role_user_to_role as r1")).left_join(db.raw(f"role_role as r2"),
                                                                                  'r1.role_id',
                                                                                  '=', 'r2.id').where_in('role',
                                                                                                         ['BX-WORKER',
                                                                                                          'CASUAL_WORKER']).count()
        bid_winning_amount = db.table('thread').sum('field_2')

        statistics = {
            'deal_orders': deal_orders,
            'number_escorters': number_escorters,
            'bid_winning_amount': bid_winning_amount if bid_winning_amount else Decimal('0.0')
        }
        return statistics, None
